\name{cause.and.effect}
\alias{cause.and.effect}
\title{Cause and effect diagram}
\description{Draw a basic cause and effect diagram.}
\usage{
cause.and.effect(cause, effect, title = "Cause-and-Effect diagram", 
                 cex = c(1, 0.9, 1), font = c(1, 3, 2))
}
\arguments{
\item{cause}{a list of causes and branches providing descriptive labels (see the example below).}
\item{effect}{a string label or the effect.}
\item{title}{a string specifying the main title to appear on the plot.}
\item{cex}{a vector of values for the graphical character expansion. The values refer, in order, to branches, causes and effect.}
\item{font}{a vector of values for the font to use. The values refer, in order, to branches, causes and effect.}
}
%\details{}
%\value{}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd
ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
\examples{
cause.and.effect(cause=list(Measurements=c("Micrometers", "Microscopes", "Inspectors"),
                            Materials=c("Alloys", "Lubricants", "Suppliers"),
                            Personnel=c("Shofts", "Supervisors", "Training", "Operators"),
                            Environment=c("Condensation", "Moisture"),
                            Methods=c("Brake", "Engager", "Angle"),
                            Machines=c("Speed", "Lathes", "Bits", "Sockets")),
                 effect="Surface Flaws")
}
\keyword{hplot}

\eof
\name{circuit}
\alias{circuit}
\docType{data}
\title{Circuit boards data}
\description{
Number of nonconformities observed in 26 successive samples of 100 printed circuit boards.
Sample 6 and 20 are outside the control limits. Sample 6 was examined by a new inspector and he did not recognize several type of nonconformities that could have been present. Furthermore, the unusually large number of nonconformities in sample 20 resulted from a temperature control problem in the wave soldering machine, which was subsequentely repaired.
The last 20 samples are further samples collected on inspection units (each formed by 100 boards).
}
\usage{data(circuit)}
\format{
  A data frame with 46 observations on the following 3 variables.
  \describe{
    \item{x}{number of defectives in 100 printed circuit boards (inspection unit)}
    \item{size}{sample size}
    \item{trial}{trial sample indicator (TRUE/FALSE)}
  }
}
%\details{}
%\source{}
\references{Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons, pp. 173--175}
\examples{
data(circuit)
attach(circuit)
summary(circuit)
boxplot(x ~ trial)
plot(x, type="b")
detach(circuit)
}
\keyword{datasets}

\eof
\name{cusum.qcc}
\alias{cusum}
\alias{cusum.default}
\alias{cusum.qcc}
\title{Cusum chart}
\description{Draw a Cusum chart from an object of class `qcc'.}
\usage{
\method{cusum}{qcc}(object, decision.int = 5, se.shift = 1,
      label.bounds = c("LDB", "UDB"), add.stats = TRUE, chart.all = TRUE, 
      ylim = NULL, axes.las = 0, restore.par = TRUE, \dots)
}
\arguments{
\item{object}{an object of class `qcc'.}

\item{decision.int}{A numeric value specifying the number of standard errors of the summary statistics at which the cumulative sum is out of control.}

\item{se.shift}{se.shift: The amount of shift to detect in the process, measured in standard errors of the summary statistics.}

\item{label.bounds}{a character vector specifying the labels for the the decision interval boundaries.}

\item{add.stats}{a logical value indicating whether statistics and other information should be printed at the bottom of the chart.}

\item{chart.all}{a logical value indicating whether both statistics for \code{data} and for \code{newdata} (if given) should be plotted.}

\item{ylim}{a numeric vector specifying the limits for the y-axis.}

\item{axes.las}{numeric in \{0,1,2,3\} specifying the style of axis labels. See \code{help(par)}.}

\item{restore.par}{a logical value indicating whether the previous \code{par} settings must be restored. If you need to add points, lines, etc. to a control chart set this to \code{FALSE}.}
\item{\dots}{}
}
\details{Cusum charts display how the group summary statistics deviate above or below the process center or target value, relative to the standard errors of the summary statistics. Useful to detect small and permanent variation on the mean of the process.
}
\value{Returns an object of class `cusum' which inherits from the `qcc' object. No methods are specifically defined for the `cusum' class.}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{ ~~further notes~~ }
\seealso{\code{\link{qcc}}, \code{\link{ewma}}}
\examples{
data(pistonrings)
attach(pistonrings)
diameter <- qcc.groups(diameter, sample)
q <- qcc(diameter[1:25,], type="xbar", nsigmas=3, plot=FALSE)
cusum(q)
q <- qcc(diameter[1:25,], type="xbar", newdata=diameter[26:40,], nsigmas=3, plot=FALSE)
cusum(q)
cusum(q, chart.all=FALSE)
cusum(qcc(diameter, type="xbar", nsigmas=3, target=74, std.dev=0.02, plot=FALSE))
}
\keyword{htest}
\keyword{hplot}

\eof
\name{dyedcloth}
\alias{dyedcloth}
\docType{data}
\title{Dyed cloth data}
\description{
In a textile finishing plant, dyed cloth is inspected for the occurrence of defects per 50 square meters. The data on ten rolls of cloth are presented.
}
\usage{data(dyedcloth)}
\format{
  A data frame with 10 observations on the following 2 variables.
  \describe{
    \item{x}{number of nonconformities per 50 square meters (inspection units)}
    \item{size}{number of inspection units in roll (variable sample size)}
  }
}
%\details{}
%\source{}
\references{Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons, pp. 183--184}
\examples{
data(dyedcloth)
attach(dyedcloth)
summary(dyedcloth)
plot(x/size, type="b")
detach(dyedcloth)
}
\keyword{datasets}

\eof
\name{ewma.qcc}
\alias{ewma}
%\alias{ewma.default}
\alias{ewma.qcc}
\title{EWMA chart}
\description{Draw an EWMA chart from an object of class `qcc'.}
\usage{
\method{ewma}{qcc}(object, lambda=0.2, nsigmas=object$nsigmas, 
     add.stats = TRUE, xlab, ylab, ylim = NULL, axes.las = 0, 
     restore.par = TRUE, \dots)
}
\arguments{
\item{object}{an object of class `qcc'.}

\item{lambda}{the smoothing parameter \eqn{0 \le \lambda \le 1}{0 <= lambda <= 1}}

\item{nsigmas}{a numeric value specifying th number of sigmas to use for computing control limits.}

\item{add.stats}{a logical value indicating whether statistics and other information should be printed at the bottom of the chart.}

\item{xlab}{a string giving the label for the x-axis.}

\item{ylab}{a string giving the label for the y-axis.}

\item{ylim}{a numeric vector specifying the limits for the y-axis.}

\item{axes.las}{numeric in \{0,1,2,3\} specifying the style of axis labels. See \code{help(par)}.}

\item{restore.par}{a logical value indicating whether the previous \code{par} settings must be restored. If you need to add points, lines, etc. to a control chart set this to \code{FALSE}.}

\item{\dots}{}
}
\details{EWMA chart smooths a series of data based on a moving average with weights which decay exponentially. Useful to detect small and permanent variation on the mean of the process.
}
\value{Returns an object of class `ewma' which inherits from the `qcc' object. No methods are specifically defined for the `ewma' class.}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{ ~~further notes~~ }
\seealso{\code{\link{qcc}}, \code{\link{ewmaSmooth}}, \code{\link{cusum}}}
\examples{
data(pistonrings)
attach(pistonrings)
diameter <- qcc.groups(diameter, sample)
q <- qcc(diameter[1:25,], type="xbar", nsigmas=3, plot=FALSE)
ewma(q, lambda=0.2)
q <- qcc(diameter[1:25,], newdata=diameter[26:40,], type="xbar", plot=FALSE)
ewma(q, lambda=0.2, nsigmas=2.7)
}
\keyword{htest}
\keyword{hplot}

\eof
\name{ewmaSmooth}
\alias{ewmaSmooth}
\title{EWMA smoothing function}
\description{Compute Exponential Weighted Moving Average.}
\usage{
ewmaSmooth(x, y, lambda = 0.2, start, \dots)
}
\arguments{
\item{x}{a vector of x-values.}
\item{y}{a vector of y-values.}
\item{lambda}{the smoothing parameter.}
\item{start}{the starting value.}
\item{\dots}{}
}
\details{
EWMA function smooths a series of data based on a moving average with weights which decay exponentially.

For each \eqn{y_t}{y_t} value the smoothed value is computed as
\deqn{z_t = \lambda y_t + (1-\lambda) z_{t-1}}
where \eqn{0 \le \lambda \le 1}{0 <= lambda <= 1} is the parameter which controls the weights applied.
}
\value{Returns a list with elements:
\item{x}{ordered x-values}
\item{y}{smoothed y-values}
\item{lambda}{the smoothing parameter}
\item{start}{the starting value}
}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd
ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{ ~~further notes~~ }
\seealso{\code{\link{qcc}}, \code{\link{cusum}}}
\examples{
x <- 1:50
y <- rnorm(50, sin(x/5), 0.5)
plot(x,y)
lines(ewmaSmooth(x,y,lambda=0.1), col="red")
}
\keyword{hplot}

\eof
\name{oc.curves}
\alias{oc.curves}
\alias{oc.curves.xbar}
\alias{oc.curves.p}
\alias{oc.curves.c}
\title{Operating Characteristic Function}
\description{Draws the operating characteristic curves for a `qcc' object.}
\usage{
oc.curves(object, \dots)

oc.curves.xbar(object, n, c = seq(0, 5, length=101), 
               nsigmas = object$nsigmas, identify=FALSE)

oc.curves.p(object, nsigmas = object$nsigmas, identify = FALSE)

oc.curves.c(object, nsigmas = object$nsigmas, identify = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{object}{an object of class `qcc'.}
\item{identify}{logical specifying whether to intercatively identify points on the plot (see help for \code{\link{identify}}).}
\item{n}{a vector of values specifying the sample sizes for which to draw the OC curves.}
\item{c}{a vector of values specifying the multipliers for sigma in case of continuous variable.}
\item{nsigmas}{a numeric value specifying th number of sigmas to use for computing control limits.}
\item{\dots}{}
}
\details{An operating characteristic curve graphically provides information about the probability of not detecting a shift in the process. \code{oc.curves} is a generic function which calls the proper function depending on the type of `qcc' object. Further arguments provided through \dots are passed to the specific function depending on the type of chart.}
}
\value{The function invisibly returns a matrix or a vector of beta values, the probability of type II error.}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd
ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{ ~~further notes~~ }
\seealso{\code{\link{qcc}}}
\examples{
data(pistonrings)
attach(pistonrings)
diameter <- qcc.groups(diameter, sample)
beta <- oc.curves.xbar(qcc(diameter, type="xbar", nsigmas=3, plot=FALSE))
print(round(beta, digits=4))
# or to identify points on the plot use
\dontrun{oc.curves.xbar(qcc(diameter, type="xbar", nsigmas=3, plot=FALSE), identify=TRUE)}
detach(pistonrings)

data(orangejuice)
attach(orangejuice)
beta <- oc.curves(qcc(D[trial], sizes=size[trial], type="p", plot=FALSE))
print(round(beta, digits=4))
# or to identify points on the plot use
\dontrun{oc.curves(qcc(D[trial], sizes=size[trial], type="p", plot=FALSE), identify=TRUE)}
detach(orangejuice)

data(circuit)
attach(circuit)
q <- qcc(x[trial], sizes=size[trial], type="c", plot=FALSE)
beta <- oc.curves(q)
print(round(beta, digits=4))
# or to identify points on the plot use
\dontrun{oc.curves(qcc(x[trial], sizes=size[trial], type="c", plot=FALSE), identify=TRUE)}
detach(circuit)
}
\keyword{htest}
\keyword{hplot}

\eof
\name{orangejuice}
\alias{orangejuice}
\docType{data}
\title{Orange juice data}
\description{
Frozen orange juice concentrate is packed in 6-oz cardboard cans. These cans are formed on a machine by spinning them from cardboard stock and attaching a metal bottom panel. A can is then inspected to determine whether, when filled, the liquid could possible leak either on the side seam or around the bottom joint. If this occurs a can is considered nonconforming.
The data were collected as 30 samples of 50 cans each at half-hour intervals over a three-shift period in which the machine was in continuous operation.
From sample 15 used a new bacth of cardboard stock was punt into production.
Sample 23 was obtained when an inexperienced operator was temporarily assigned to the machine.
After the first 30 samples, a machine adjustment was made. Then further 24 samples were taken from the process.
}
\usage{data(orangejuice)}
\format{A data frame with 54 observations on the following 4 variables:
\describe{\item{sample}{sample id}
          \item{D}{number of defectives}
          \item{size}{sample sizes}
          \item{trial}{trial samples (TRUE/FALSE)}
         }
}
%\details{}
%\source{}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons, pp. 152--155.
}
\examples{
data(orangejuice)
orangejuice$d <- orangejuice$D/orangejuice$size
attach(orangejuice)
summary(orangejuice)
boxplot(d ~ trial)
mark <- ifelse(trial, 1, 2)
plot(sample, d, type="b", col=mark, pch=mark)
}
\keyword{datasets}

\eof
\name{orangejuice2}
\alias{orangejuice2}
\docType{data}
\title{Orange juice data --  Part 2}
\description{
A full description of the problem is given in \code{\link{orangejuice}}. \cr

This dataset contains samples taken after the machine adjustment was made. 
}
\usage{data(orangejuice)}
\format{
A data frame with 64 observations on the following 4 variables:
\describe{\item{sample}{sample id}
          \item{D}{number of defectives}
          \item{size}{sample sizes}
          \item{trial}{trial samples (TRUE/FALSE)}
         }
}
%\details{}
%\source{}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons, pp. 155--159.
}
\examples{
data(orangejuice2)
orangejuice2$d <- orangejuice2$D/orangejuice2$size
attach(orangejuice2)
summary(orangejuice2)
boxplot(d ~ trial)
mark <- ifelse(trial, 1, 2)
plot(sample, d, type="b", col=mark, pch=mark)
}
\keyword{datasets}

\eof
\name{pareto.chart}
\alias{pareto.chart}
\title{Pareto chart}
\description{Plot a Pareto chart.}
\usage{
pareto.chart(x, ylab = "Frequency", xlab, ylim, main, 
             col = heat.colors(length(x)), print = TRUE, \dots)
}
\arguments{
\item{x}{a vector of values. \code{names(x)} are used for labelling the bars.}
\item{ylab}{a string specifying the label for the y-axis.}
\item{xlab}{a string specifying the label for the x-axis.}
\item{ylim}{a numeric vector specifying the limits for the y-axis.}
\item{main}{a string specifying the main title to appear on the plot.}   \item{col}{a value for the color, a vector of colors, or a palette for the bars. See the help for \code{colors} and \code{palette}.}
\item{print}{logical, if \code{TRUE} a frequency table distribution for \code{x} is printed.}
\item{\dots}{other graphical arguments to be passed to the \code{barplot} function.}
}
\details{A Pareto chart is a barplot where the categories are ordered in non increasing order, and a line is also added to show the cumulative sum.}
%\value{}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd
ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
\seealso{\code{\link{barplot}}}
\examples{
defect <- c(80, 27, 66, 94, 33)
names(defect) <- c("price code", "schedule date", "supplier code", "contact num.", "part num.")
pareto.chart(defect, ylab = "Error frequency")
pareto.chart(defect, ylab = "Error frequency", xlab = "Error causes", las=1)
pareto.chart(defect, ylab = "Error frequency", col=rainbow(length(defect)))
}
\keyword{hplot}

\eof
\name{pcmanufact}
\alias{pcmanufact}
\docType{data}
\title{Personal computer manufacturer data}
\description{
A personal computer manufacturer counts the number of nonconformities per unit on the final assembly line. He collects data on 20 samples of 5 computers each.
}
\usage{data(pcmanufact)}
\format{
  A data frame with 10 observations on the following 2 variables.
  \describe{
    \item{x}{number of nonconformities (inspection units)}
    \item{size}{number of computers inspected}
  }
}
%\details{}
%\source{}
\references{Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons, pp. 181--182}
\examples{
data(pcmanufact)
attach(pcmanufact)
summary(pcmanufact)
plot(x/size, type="b")
detach(pcmanufact)
}
\keyword{datasets}

\eof
\name{pistonrings}
\alias{pistonrings}
\docType{data}
\title{Piston rings data}
\description{
Piston rings for an automotive engine are produced by a forging process. The inside diameter of the rings manufactured by the process is measured on 25 samples, each of size 5, drawn from a process being considered `in control'.
}
\usage{data(pistonrings)}
\format{
  A data frame with 200 observations on the following 3 variables.
  \describe{
    \item{diameter}{a numeric vector}
    \item{sample}{sample ID}
    \item{trial}{trial sample indicator (TRUE/FALSE)}
  }
}
%\details{}
%\source{}
\references{Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons, pp. 206--213}
\examples{
data(pistonrings)
attach(pistonrings)
summary(pistonrings)
boxplot(diameter ~ sample)
plot(sample, diameter, cex=0.7)
lines(tapply(diameter,sample,mean))
detach(pistonrings)
}
\keyword{datasets}

\eof
\name{process.capability}
\alias{process.capability}
\title{Process capability analysis}
\description{Computes process capability indices for a `qcc' object of type \code{"xbar"} and plot the histogram.}
}
\usage{
process.capability(object,spec.limits, target, std.dev, nsigmas, 
                   confidence.level = 0.95, breaks = "scott", 
                   add.stats = TRUE, print = TRUE, restore.par = TRUE)
}
\arguments{
\item{object}{a `qcc' object of type \code{"xbar"}}
\item{spec.limits}{a vector specifying the lower and upper specification limits.}
\item{target}{a value specifying the target of the process. If missing the value from the `qcc' object is used if not \code{NULL}, otherwise the target is set at the middle value bewteen specification limits.}
\item{std.dev}{a value specifying the within-group standard deviation. If not provided is taken from the `qcc' object.}
\item{nsigmas}{a numeric value specifying the number of sigmas to use. If not provided is taken from the `qcc' object.}
\item{confidence.level}{a numeric value between 0 and 1 specifying the level to use for computing confidence intervals.}
\item{breaks}{a value or string used to draw the histogram. See the help for  \code{\link{hist}} for more details. }
\item{add.stats}{a logical value indicating whether statistics and capability indices should be added at the bottom of the chart.}
\item{print}{a logical value indicating whether statistics and capability indices should be printed.}
\item{restore.par}{a logical value indicating whether the previous \code{par} settings must be restored. If you need to add points, lines, etc. to a chart set this to \code{FALSE}.}
}
\details{
This function calculates confidence limits for \eqn{C_p}{C_p} using the method described by Chou et al. (1990). 
Approximate confidence limits for \eqn{C_{pl}}{C_pl}, \eqn{C_{pu}}{C_pu} and  \eqn{C_{pk}}{C_pk} are computed using the method in Bissell (1990).  
Confidence limits for \eqn{C_{pm}}{C_pm} are based on the method of Boyles (1991); this method is approximate and it assumes that the target is midway between the specification limits.
}
\value{Invisibly returns a list with components:
\item{nobs}{number of obserations}
\item{center}{center}
\item{std.dev}{standard deviation}
\item{target}{target}
\item{spec.limits}{a vector of values giving the lower specification limit (LSL) and the upper specification limit (USL)}
\item{indices}{a matrix of capability indices (\eqn{C_p}{C_p}, \eqn{C_{pl}}{C_pl}, \eqn{C_{pu}}{C_pu}, \eqn{C_{pk}}{C_pk}, \eqn{C_{pm}}{C_pm}) and the corresponding confindence limits.}
\item{exp}{a vector of values giving the expected fraction, based on a normal approximation, of the observations less than LSL and greater than USL.}
\item{obs}{a vector of values giving the fraction of observations less than LSL and greater than USL.}
}
\references{
Bissell, A.F. (1990) \emph{How reliable is your capability index?}, Applied Statistics, 39, 331-340. \cr
Boyles, R.A. (1991) \emph{The Taguchi capability index}, Journal of Quality Technology, 23, 107-126. \cr
Chou, Y., Owen D.B. and Borrego S.A. (1990) \emph{Lower Confidence Limits on Process Capability Indices}, Journal of Quality Technology, 22, 223-229. \cr
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd
ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall. 
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
\seealso{\code{\link{process.capability.sixpack}}, \code{\link{qcc}}}
\examples{
data(pistonrings)
attach(pistonrings)
diameter <- qcc.groups(diameter, sample)
q <- qcc(diameter[1:25,], type="xbar", nsigmas=3, plot=FALSE)
process.capability(q, spec.limits=c(73.95,74.05))
process.capability(q, spec.limits=c(73.95,74.05), target=74.02)
process.capability(q, spec.limits=c(73.99,74.01))
process.capability(q, spec.limits = c(73.99, 74.1))
}
\keyword{htest}
\keyword{hplot}


\eof
\name{process.capability.sixpack}
\alias{process.capability.sixpack}
\title{Process capability sixpack plots}
\description{Draw a process capability sixpack plots.}
}
\usage{
process.capability.sixpack(object, spec.limits, target, nsigmas, std.dev)
}
\arguments{
\item{object}{a `qcc' object of type \code{"xbar"}}
\item{spec.limits}{a vector specifying the lower and upper specification limits.}
\item{target}{a value specifying the target of the process. If missing the value from the `qcc' object is used if not \code{NULL}, otherwise the target is set at the middle value bewteen specification limits.}
\item{nsigmas}{a numeric value specifying th number of sigmas to use. If not provided is taken from the `qcc' object.}
\item{std.dev}{a value specifying the within-group standard deviation. If not provided is taken from the `qcc' object.}
}
\details{The process capability sixpack plots are: \cr
a xbar chart \cr
a R or S chart (if sample sizes > 10) \cr
a run chart \cr
a histogram \cr
a normal Q-Q plot \cr
a capability plot 
}
%\value{}
\references{
Minitab (2000) \emph{Users's Guide 2: Data Analysis and Quality Tools}, rel. 13, Chapter 14. 
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
\seealso{\code{\link{process.capability}}, \code{\link{qcc}}}
\examples{
x <- matrix(rnorm(100), ncol=5)
q <- qcc(x, type="xbar", plot=FALSE)
process.capability.sixpack(q, spec.limits = c(-2,2), target=0)

data(pistonrings)
attach(pistonrings)
diameter <- qcc.groups(diameter, sample)
q <- qcc(diameter[1:25,], type="xbar", nsigmas=3, plot=FALSE)
process.capability.sixpack(q, spec.limits=c(73.95,74.05))
}
\keyword{htest}
\keyword{hplot}


\eof
\name{qcc}
\alias{qcc}
\alias{print.qcc}
\alias{summary.qcc}
\alias{plot.qcc}
\title{Quality Control Charts}
\description{Create an object of class `qcc' to perform statistical quality control. This object may then be used to plot Shewhart charts, Cusum and EWMA plotting, drawing OC curves, computes capability indices, and more.}
\usage{
qcc(data, type, std.dev, sizes, limits, target, data.name, labels, 
    newdata, newsizes, newlabels, 
    nsigmas = 3, confidence.level, rules = shewhart.rules, 
    plot = TRUE, \dots)

\method{print}{qcc}(x, \dots)

\method{summary}{qcc}(object, \dots)

\method{plot}{qcc}(x, add.stats = TRUE, chart.all = TRUE, 
     label.limits = c("LCL ", "UCL"), title, xlab, ylab, ylim, 
     axes.las = 0, restore.par = TRUE, \dots)
}
\arguments{

  \item{data}{a data frame, a matrix or a vector containing observed data for
  the variable to chart. Each row of a data frame or a matrix, and each
  value of a vector, refers to a sample or ``rationale group''.}

  \item{type}{a character string specifying the group statistics to compute:

\tabular{lll}{
              \tab Statistic charted   \tab Chart description \cr
\code{"xbar"} \tab mean                \tab means of a continuous process variable \cr
\code{"S"}    \tab standard deviation  \tab stdandard deviations of a continuous variable \cr
\code{"R"}    \tab range               \tab ranges of a continuous process variable \cr
\code{"xbar.one"} \tab mean            \tab one-at-time data of a continuous process variable \cr
\code{"p"}    \tab proportion          \tab proportion of nonconforming units \cr
\code{"np"}   \tab count               \tab number of nonconforming units \cr
\code{"c"}    \tab count               \tab nonconformities per unit \cr
\code{"u"}    \tab count               \tab average nonconformities per unit
}
}

\item{std.dev}{a value or a vector of values specifying the within-group standard deviation(s) of the process.}

\item{sizes}{a value or a vector of values specifying the sample sizes associated with each group. For continuous data provided as data frame or matrix the sample sizes are obtained counting the non-\code{NA} elements of each row. For \code{"p"}, \code{"np"} and \code{"u"} charts the argument \code{sizes} is required.}

\item{limits}{a two-values vector specifying control limits.}

\item{target}{a value specifying the ``target'' value of the process.}

\item{data.name}{a string specifying the name of the variable which appears on the plots. If not provided is taken from the object given as data.}

\item{labels}{a character vector of labels for each group.}

\item{newdata}{a data frame, matrix or vector, as for the \code{data} argument, providing further data to plot but not included in the computations.}

\item{newsizes}{a vector as for the \code{sizes} argument providing further data sizes to plot but not included in the computations.}

\item{newlabels}{a character vector of labels for each new group defined in the argument \code{newdata}.}

\item{nsigmas}{a numeric value specifying th number of sigmas to use for computing control limits. It is ignored when the \code{confidence.level} argument is  provided.} 

\item{confidence.level}{a numeric value between 0 and 1 specifying the confidence level of the computed probability limits.} 

\item{rules}{a function of rules to apply to the chart. By default, the \code{shewhart.rules} function is used.}

\item{plot}{logical. If \code{TRUE} a Shewhart chart is plotted.}

\item{add.stats}{a logical value indicating whether statistics and other information should be printed at the bottom of the chart.}

\item{chart.all}{a logical value indicating whether both statistics for \code{data} and for \code{newdata} (if given) should be plotted.}

\item{label.limits}{a character vector specifying the labels for control limits.}

\item{title}{a string giving the label for the main title.}

\item{xlab}{a string giving the label for the x-axis.}
 
\item{ylab}{a string giving the label for the y-axis.}

\item{ylim}{a numeric vector specifying the limits for the y-axis.}

\item{axes.las}{numeric in \{0,1,2,3\} specifying the style of axis labels. See \code{help(par)}.}

\item{restore.par}{a logical value indicating whether the previous \code{par} settings must be restored. If you need to add points, lines, etc. to a control chart set this to \code{FALSE}.}

\item{object}{an object of class `qcc'.}

\item{x}{an object of class `qcc'.}

\item{\dots}{additional arguments to be passed to the plotting function.} 
}
%\details{}
\value{Returns an object of class `qcc'}
\references{
Montgomery, D.C. (1991) \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{ ~~further notes~~ }
\seealso{\code{\link{shewhart.rules}}, \code{\link{cusum}}, \code{\link{ewma}}, \code{\link{process.capability}}, \code{\link{qcc.groups}} }
\examples{
data(pistonrings)
attach(pistonrings)
diameter <- qcc.groups(diameter, sample)

qcc(diameter[1:25,], type="xbar")
qcc(diameter[1:25,], type="xbar", newdata=diameter[26:40,])
q <- qcc(diameter[1:25,], type="xbar", newdata=diameter[26:40,], plot=FALSE)
plot(q, chart.all=FALSE)
qcc(diameter[1:25,], type="xbar", newdata=diameter[26:40,], nsigmas=2)
qcc(diameter[1:25,], type="xbar", newdata=diameter[26:40,], confidence.level=0.99)

qcc(diameter[1:25,], type="R")
qcc(diameter[1:25,], type="R", newdata=diameter[26:40,])

qcc(diameter[1:25,], type="S")
qcc(diameter[1:25,], type="S", newdata=diameter[26:40,])

# variable control limits

out <- c(9, 10, 30, 35, 45, 64, 65, 74, 75, 85, 99, 100)
diameter <- qcc.groups(pistonrings$diameter[-out], sample[-out])

qcc(diameter[1:25,], type="xbar")
qcc(diameter[1:25,], type="R")
qcc(diameter[1:25,], type="S")
qcc(diameter[1:25,], type="xbar", newdata=diameter[26:40,])
qcc(diameter[1:25,], type="R", newdata=diameter[26:40,])
qcc(diameter[1:25,], type="S", newdata=diameter[26:40,])

detach(pistonrings)

##
##  Attribute data 
##

data(orangejuice)
attach(orangejuice)
qcc(D[trial], sizes=size[trial], type="p")

# remove out-of-control points (see help(orangejuice) for the reasons)
inc <- setdiff(which(trial), c(15,23))
q1 <- qcc(D[inc], sizes=size[inc], type="p")
qcc(D[inc], sizes=size[inc], type="p", newdata=D[!trial], newsizes=size[!trial]) 
detach(orangejuice)

data(orangejuice2)
attach(orangejuice2)
names(D) <- sample
qcc(D[trial], sizes=size[trial], type="p")
q2 <- qcc(D[trial], sizes=size[trial], type="p", newdata=D[!trial], newsizes=size[!trial])
detach(orangejuice2)

# put on the same graph the two orange juice samples
oldpar <- par(no.readonly = TRUE)
par(mfrow=c(1,2), mar=c(5,5,3,0))
plot(q1, title="First samples", ylim=c(0,0.5), add.stats=FALSE, restore.par=FALSE)
par("mar"=c(5,0,3,3), yaxt="n")
plot(q2, title="Second sample", add.stats=FALSE, ylim=c(0,0.5))
par(oldpar)

data(circuit)
attach(circuit)
qcc(x[trial], sizes=size[trial], type="c")
# remove out-of-control points (see help(circuit) for the reasons)
inc <- setdiff(which(trial), c(6,20))
qcc(x[inc], sizes=size[inc], type="c", labels=inc)
qcc(x[inc], sizes=size[inc], type="c", labels=inc, 
    newdata=x[!trial], newsizes=size[!trial], newlabels=which(!trial))
qcc(x[inc], sizes=size[inc], type="u", labels=inc, 
    newdata=x[!trial], newsizes=size[!trial], newlabels=which(!trial))
detach(circuit)

data(pcmanufact)
attach(pcmanufact)
qcc(x, sizes=size, type="u")
detach(pcmanufact)

data(dyedcloth)
attach(dyedcloth)
qcc(x, sizes=size, type="u")
# standardized control chart
q <- qcc(x, sizes=size, type="u", plot=FALSE)
z <- (q$statistics - q$center)/sqrt(q$center/q$size)
plot(z,  type="o", ylim=range(z,3,-3), pch=16)
abline(h=0, lty=2)
abline(h=c(-3,3), lty=2)
detach(dyedcloth)

# viscosity data (Montgomery, pag. 242)
x <- c(33.75, 33.05, 34, 33.81, 33.46, 34.02, 33.68, 33.27, 33.49, 33.20,
       33.62, 33.00, 33.54, 33.12, 33.84)
qcc(x, type="xbar.one")
}
\keyword{htest}
\keyword{hplot}

\eof
\name{qcc.groups}
\alias{qcc.groups}

\title{Grouping data based on a sample indicator}
\description{This function allows to easily group data to use as input to the `qcc' function.}
\usage{
qcc.groups(data, sample)
}
\arguments{
  \item{data}{the observed data values}
  \item{sample}{the sample indicators for the data values}
}
%\details{}
\value{
The function returns a matrix of suitable dimensions. If one or more group have few observations than others, \code{NA} values are appended.
}
%\references{}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
\examples{
data(pistonrings)
attach(pistonrings)
# 40 sample of 5 obs each
qcc.groups(diameter, sample)
# some obs are removed, the result is still a 40x5 matrix but with NAs added
qcc.groups(diameter[-c(1,2,50,52, 199)], sample[-c(1,2,50,52, 199)])
}
\keyword{}


\eof
\name{qcc.options}
\alias{qcc.options}
\alias{.qcc.options}

\title{Set or return options for the `qcc' package.}

\description{This function can be used to control the behavior of the
`qcc' library such as the background color, out-of-control points appearance,
 and many others.}
\usage{qcc.options(\dots)}
\arguments{
\item{\dots}{the option to be set or retrieved. See details.}
}
\details{
The available options are:
\describe{

\item{\code{exp.R.unscaled}}{a vector specifying, for each sample size, the expected value of the relative range (i.e. \eqn{R/\sigma}) for a normal distribution. This appears as \eqn{d_2} on most tables containing factors for the construction of control charts.}

\item{\code{se.R.unscaled}}{a vector specifying, for each sample size, the standard error of the relative range (i.e. \eqn{R/\sigma}) for a normal distribution. This appears as \eqn{d_3} on most tables containing factors for the construction of control charts.}

\item{\code{beyond.limits$pch}}{plotting character used to highlight points beyond control limits.}  

\item{\code{beyond.limits$col}}{color used to highlight points beyond control limits.}  

\item{\code{violating.runs$pch}}{plotting character used to highlight points violating runs.}

\item{\code{violating.runs$col}}{color used to highlight points violating runs.}  

\item{\code{run.length}}{the maximum value of a run before to signal a point as out of control.}  

\item{\code{bg.margin}}{background color used to draw the margin of the charts.} 

\item{\code{bg.figure}}{background color used to draw the figure of the charts.}

\item{\code{cex}}{character expansion used to draw labels, title, statistics at the bottom of plot produced by this package.}
} 
}
\value{
If the functions is called with no argument return a list of available options. 

If an option argument is provided the corresponding value is returned. 

If a value is associated with an option argument, such option is set and the list of updated option values is invisibly returned.
In this case the list \code{.qcc.options} is modified and any modification will remain in effect for the rest of the session.
}

\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
\examples{
qcc.options()
qcc.options("cex")
qcc.options("cex"=2)
qcc.options(bg.margin="yellow")
}
\keyword{htest}
\keyword{hplot}


\eof
\name{qcc.overdispersion.test}
\alias{qcc.overdispersion.test}

\title{Overdispersion test for binomial and poisson data}
\description{This function allows to test for overdispersed data in the binomial and poisson case.}
\usage{
qcc.overdispersion.test(x, size, type=ifelse(missing(size), "poisson", "binomial"))
}
\arguments{
  \item{x}{a vector of observed data values}
  \item{size}{for binomial data, a vector of sample sizes}
  \item{type}{a character string specifying the distribution for testing, either \code{"poisson"} or \code{"binomial"}. By default, if \code{size} is provided a binomial distributed is assumed, otherwise a poisson distribution.}
}  
\details{
This very simple test amounts to compute the statistic 
\tabular{c}{
D = Observed variance / Theoretical variance \eqn{\times} (no. observations - 1)}
and refer this to a Chi-square distribution with (no. observations - 1) degrees of freedom.}
\value{The function returns a matrix of results.}
\references{Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall, pp. 216--218}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
%\seealso{}
\examples{
# data from Wetherill and Brown (1991) pp. 212--213, 216--218:
x <- c(12,11,18,11,10,16,9,11,14,15,11,9,10,13,12,
       8,12,13,10,12,13,16,12,18,16,10,16,10,12,14)
size <- rep(50, length(x))
qcc.overdispersion.test(x,size)

x <- c(11,8,13,11,13,17,25,23,11,16,9,15,10,16,12,
       8,9,15,4,12,12,12,15,17,14,17,12,12,7,16)
qcc.overdispersion.test(x)
}
\keyword{}


\eof
\name{shewhart.rules}
\alias{shewhart.rules}
\alias{beyond.limits}
\alias{violating.runs}
\title{Functions specifying rules for Shewhart charts}
\description{
These functions are used to signal out of control points in Shewhart charts.}
\usage{
shewhart.rules(object, run.length = qcc.options("run.length"))
beyond.limits(object)
violating.runs(object, run.length = qcc.options("run.length"))
}
\arguments{
  \item{object}{an object of class `qcc'.}
  \item{run.length}{the maximum value of a run before to signal a
  point as out of control.}
}
\details{
The function \code{shewhart.rules} simply calls the \code{beyond.limits} and \code{violating.runs} functions which actually do the real calculations.
}
\value{
The \code{shewhart.rules} function returns a list with components:
\item{beyond.limits}{the indices of points beyond control limits.}
\item{violating.runs}{the indices of points violating runs.}
}
%\references{ ~put references to the literature/web site here ~ }
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{ ~~further notes~~ }
%\examples{}
\keyword{hplot}

\eof
\name{stats.R}
\alias{stats.R}
\alias{sd.R}
\alias{limits.R}

\title{Functions to plot Shewhart R chart}
\description{These functions are used to compute statistics required by the R chart.}
\usage{
stats.R(data, sizes)
sd.R(data, sizes, std.dev, equal.sd = TRUE)
limits.R(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes. Optional}
  \item{std.dev}{within group standard deviation. Optional for \code{sd.R} function, required for \code{limits.R}}
  \item{equal.sd}{a logical indicating whether the standard deviation is constant for all samples/groups.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.R} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.R} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.R} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.S}
\alias{stats.S}
\alias{sd.S}
\alias{limits.S}

\title{Functions to plot Shewhart S chart}
\description{These functions are used to compute statistics required by the S chart.}
\usage{
stats.S(data, sizes)
sd.S(data, sizes, std.dev, equal.sd = TRUE)
limits.S(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes. Optional}
  \item{std.dev}{within group standard deviation. Optional for \code{sd.S} function, required for \code{limits.S}}
  \item{equal.sd}{a logical indicating whether the standard deviation is constant for all samples/groups.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.S} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.S} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.S} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.c}
\alias{stats.c}
\alias{sd.c}
\alias{limits.c}

\title{Functions to plot Shewhart c chart}
\description{These functions are used to compute statistics required by the c chart.}
\usage{
stats.c(data, sizes)
sd.c(data, sizes)
limits.c(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes.}
  \item{std.dev}{within group standard deviation.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.c} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.c} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.c} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.np}
\alias{stats.np}
\alias{sd.np}
\alias{limits.np}

\title{Functions to plot Shewhart np chart}
\description{These functions are used to compute statistics required by the np chart.}
\usage{
stats.np(data, sizes)
sd.np(data, sizes)
limits.np(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes.}
  \item{std.dev}{within group standard deviation.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.np} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.np} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.np} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.p}
\alias{stats.p}
\alias{sd.p}
\alias{limits.p}

\title{Functions to plot Shewhart p chart}
\description{These functions are used to compute statistics required by the p chart.}
\usage{
stats.p(data, sizes)
sd.p(data, sizes)
limits.p(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes.}
  \item{std.dev}{within group standard deviation.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.p} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.p} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.p} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.u}
\alias{stats.u}
\alias{sd.u}
\alias{limits.u}

\title{Functions to plot Shewhart u chart}
\description{These functions are used to compute statistics required by the u chart.}
\usage{
stats.u(data, sizes)
sd.u(data, sizes)
limits.u(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes.}
  \item{std.dev}{within group standard deviation.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.u} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.u} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.u} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.xbar}
\alias{stats.xbar}
\alias{sd.xbar}
\alias{limits.xbar}

\title{Functions to plot Shewhart xbar chart}
\description{These functions are used to compute statistics required by the xbar chart.}
\usage{
stats.xbar(data, sizes)
sd.xbar(data, sizes, std.dev, equal.sd = TRUE)
limits.xbar(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes. Optional}
  \item{std.dev}{within group standard deviation. Optional for \code{sd.xbar} function, required for \code{limits.xbar}}
  \item{equal.sd}{a logical indicating whether the standard deviation is constant for all samples/groups.}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.xbar} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.xbar} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.xbar} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
%\examples{}
\keyword{htest}
\keyword{hplot}


\eof
\name{stats.xbar.one}
\alias{stats.xbar.one}
\alias{sd.xbar.one}
\alias{limits.xbar.one}

\title{Functions to plot Shewhart xbar chart for one-at-time data}
\description{These functions are used to compute statistics required by the xbar chart for one-at-time data.}
\usage{
stats.xbar.one(data, sizes)
sd.xbar.one(data, sizes, std.dev, k=2)
limits.xbar.one(center, std.dev, sizes, conf)
}
\arguments{
  \item{data}{the observed data values}
  \item{center}{sample/group center statistic.}
  \item{sizes}{samples sizes. Not needed, size=1 is used.}
  \item{k}{number of successive pairs of observations for computing the standard deviation based on moving ranges of k points.}
  \item{std.dev}{within group standard deviation. Optional for \code{sd.xbar.one} function, required for \code{limits.xbar.one}}
  \item{conf}{a numeric value used to compute control limits, specifying the number of standard deviations (if \code{conf} > 1) or the confidence level (if 0 < \code{conf} < 1).}
}
%\details{}
\value{
The function \code{stats.xbar.one} returns a list with components \code{statistics} and \code{center}.

The function \code{sd.xbar.one} returns \code{std.dev} the standard deviation of the statistic charted.

The function \code{limits.xbar.one} returns a matrix with lower and upper control limits. 
}
\references{
Montgomery, D.C. (1991)  \emph{Introduction to Statistical Quality Control}, 2nd ed, New York, John Wiley & Sons. \cr
Wetherill, G.B. and Brown, D.W. (1991) \emph{Statistical Process
Control}, New York, Chapman and Hall.
}
\author{Luca Scrucca \email{luca@stat.unipg.it}}
%\note{}
\seealso{\code{\link{qcc}} }
\examples{
# Water content of antifreeze data (Wetherill and Brown, 1991, p. 120)
x <- c(2.23, 2.53, 2.62, 2.63, 2.58, 2.44, 2.49, 2.34, 2.95, 2.54, 2.60, 2.45,
       2.17, 2.58, 2.57, 2.44, 2.38, 2.23, 2.23, 2.54, 2.66, 2.84, 2.81, 2.39,
       2.56, 2.70, 3.00, 2.81, 2.77, 2.89, 2.54, 2.98, 2.35, 2.53)
sigma <- NA
k <- 2:24
for (j in k)
    sigma[j] <- sd.xbar.one(x, k=j)
# plot estimates of sigma for different values of k
plot(k, sigma[k], type="b")
# "as the size inceases further, we would expect sigma-hat to settle down
#  at a value close to the overall sigma-hat" (p. 121)
abline(h=sd(x), col=2, lty=2)

# the Shewhart control chart for one-at-time data
qcc(x, type="xbar.one", data.name="Water content (in ppm) of batches of antifreeze")
}
\keyword{htest}
\keyword{hplot}


\eof
